@@ -23,11 +23,11 @@ logging.basicConfig(format='%(asctime)s %(levelname)s - %(message)s', level=logg
 home = str(Path.home())
 
 url = "https://www.discogs.com/fr/settings/developers"
-database = list()
+database = dict()
 
 config = configparser.ConfigParser()
 config_file = Path(home + "/.config/discoger/config.ini")
-data_file = Path(home + "/.config/discoger/database.yaml")
+database_dir = Path(home + "/.config/discoger/databases")
 
 if config_file.exists():
     config.read(config_file)
@@ -35,6 +35,10 @@ else:
     print("No config file")
     exit()
 
+if not database_dir.exists():
+    database_dir.mkdir(parents=True, exist_ok=True)
+
+
 schedule_logger = logging.getLogger('schedule')
 logger = telebot.logger
 
@@ -78,21 +82,47 @@ def bot_polling():
 
 @bot.message_handler(commands=['help', 'start'])
 def send_welcome(message):
+    chat_id = message.chat.id
+    if Path("%s/.config/discoger/databases/%s.yaml" % (home, chat_id)).exists():
+        msg = "Hi there, I am Discoger bot"
+        bot.reply_to(message, msg)
+        process_hi_step(chat_id)
+    else:
+        msg = "Hi new user, I am Discorger bot. Can you give me your list on ID of the list i need follow ?"
+        answer = bot.reply_to(message, msg)
+        bot.register_next_step_handler(answer, process_save_step)
+
+
+def process_hi_step(chat_id):
     markup = types.ReplyKeyboardMarkup()
     itembtna = types.KeyboardButton('/help')
     itembtnb = types.KeyboardButton('/check')
     markup.row(itembtna, itembtnb)
-    bot.reply_to(message, """\
-Hi there, I am Discoger bot.
-What do you want?
-""", reply_markup=markup)
+    msg = "What do you want?"
+    bot.send_message(chat_id, msg, reply_markup=markup)
+
+
+def process_save_step(message):
+    data_to_save = dict()
+    chat_id = message.chat.id
+    id_list = message.text
+    data_file = Path("%s/.config/discoger/databases/%s.yaml" % (home, chat_id))
+    data_to_save["id_list"] = id_list
+    data_to_save["release_list"] = list()
+    with open(data_file, 'w') as file:
+        yaml.dump(data_to_save, file)
+        file.close()
+    msg = "Thanks, i added your list in my database"
+    bot.reply_to(message, msg)
+    process_hi_step(chat_id)
 
 
 @bot.message_handler(commands=['check'])
 def get_check(message):
     chat_id = message.chat.id
+    data_file = Path("%s/.config/discoger/databases/%s.yaml" % (home, chat_id))
     bot.send_message(chat_id, "Okay i check your discogs list")
-    check_discogs()
+    check_discogs(data_file)
 
 
 def market_scrape(release_id, title, last_one):
@@ -137,10 +167,10 @@ def market_scrape(release_id, title, last_one):
         if new_one:
             logging.info("There are new sale\n")
             send_msg(title=title, data=this_dict)
+        print(this_dict)
         return this_dict
 
 
-
 def send_msg(title, data):
     url = data.get("url")
     date = data.get("date")
@@ -151,14 +181,14 @@ def send_msg(title, data):
 
 def get_data(release_id):
     data = dict()
-    for i in database:
+    for i in user_data["release_list"]:
         if release_id == i.get("id"):
             data = i
             return data
 
 
 def check_exist(release_id, id_sell):
-    for i in database:
+    for i in user_data["release_list"]:
         if release_id == i.get("id"):
             if id_sell == i.get("id_sell"):
                 return True
@@ -166,7 +196,7 @@ def check_exist(release_id, id_sell):
 
 
 def check_date(id):
-    for i in database:
+    for i in user_data["release_list"]:
         if id == i.get("id"):
             last_one = i.get("date")
             return last_one
@@ -174,13 +204,23 @@ def check_date(id):
     return last_one
 
 
-def check_discogs():
-    data_to_save = list()
-    if data_file.exists():
-        with open(data_file) as file:
-            global database
-            database = yaml.full_load(file)
-    id_list = config["discogs"]["id_list"]
+def check_discogs(data_file):
+    if data_file:
+        logging.info("Check user list")
+        scrap_data(data_file)
+    else:
+        logging.info("Check all list")
+        for x in database_dir.iterdir():
+            scrap_data(x)
+
+
+def scrap_data(data_file):
+    data_to_save = dict()
+    with open(data_file) as file:
+        global user_data
+        user_data = yaml.full_load(file)
+    data_to_save["release_list"] = list()
+    id_list = user_data["id_list"]
     list_notif = client.list(id_list)
     logging.info("Check if there are new a new sale for:")
     for item in list_notif.items:
@@ -188,9 +228,10 @@ def check_discogs():
         logging.info(str(item.id) + ": " + item.display_title)
         data_from_item = market_scrape(item.id, item.display_title, last_one)
         if data_from_item:
-            data_to_save.append(data_from_item)
-    while {} in data_to_save:
-        data_to_save.remove({})
+            data_to_save["release_list"].append(data_from_item)
+    while {} in data_to_save["release_list"]:
+        data_to_save["release_list"].remove({})
+    data_to_save["id_list"] = id_list
     with open(data_file, 'w') as file:
         yaml.dump(data_to_save, file)
         file.close()
@@ -202,7 +243,7 @@ def run_threaded(job_func):
 
 
 def main():
-    schedule.every(int(config["DEFAULT"]["schedule_time"])).minutes.do(run_threaded, check_discogs)
+    schedule.every(int(config["DEFAULT"]["schedule_time"])).minutes.do(run_threaded, check_discogs(None))
     polling_thread = threading.Thread(target=bot_polling)
     polling_thread.daemon = True
     polling_thread.start()
